# Changelog

## [0.2.1](https://github.com/TheoEwzZer/WinSight-MCP/compare/winsight-mcp-v0.2.0...winsight-mcp-v0.2.1) (2026-02-13)


### Bug Fixes

* **ci:** use release/v1 branch for pypi-publish action ([63ee1ed](https://github.com/TheoEwzZer/WinSight-MCP/commit/63ee1edb31d24b2822e96e044387da50776b152b))

## [0.2.0](https://github.com/TheoEwzZer/WinSight-MCP/compare/winsight-mcp-v0.1.3...winsight-mcp-v0.2.0) (2026-02-13)


### ⚠ BREAKING CHANGES

* remove run_python_script tool and bump to 0.1.2

### Features

* add window management and monitor tools ([57e5eb3](https://github.com/TheoEwzZer/WinSight-MCP/commit/57e5eb3a841d1330d471b3f572195c428d443452))
* initial release of WinSight MCP server ([c8ba242](https://github.com/TheoEwzZer/WinSight-MCP/commit/c8ba2424ab55751e012b030834f0259a730dd533))
* remove run_python_script tool and bump to 0.1.2 ([0777ee2](https://github.com/TheoEwzZer/WinSight-MCP/commit/0777ee2b81b91d20befd907dc46fc7ec595c1883))


### Bug Fixes

* **screenshot:** ensure Win32 resource cleanup on conversion failure ([de37335](https://github.com/TheoEwzZer/WinSight-MCP/commit/de37335696c22ca25e1d87609c05fc576bff82e9))


### Miscellaneous

* add all commit types to changelog sections ([05c800f](https://github.com/TheoEwzZer/WinSight-MCP/commit/05c800f28c8206089f63f3100940689eda3b04c9))
* add coverage and pytest cache to gitignore ([2735d19](https://github.com/TheoEwzZer/WinSight-MCP/commit/2735d19454f6f9db4466b97a6f4684271fe1fa36))
* add MCP Registry config and bump version to 0.1.1 ([be5175b](https://github.com/TheoEwzZer/WinSight-MCP/commit/be5175bdfeda320ec0bb55c51373cee04acba363))
* add Python 3.14 classifier ([16c396c](https://github.com/TheoEwzZer/WinSight-MCP/commit/16c396c6297e42de900630bd527e5b336c91ee17))
* bump version to 0.1.3 ([af98abc](https://github.com/TheoEwzZer/WinSight-MCP/commit/af98abce765b616f8c859adcca691c4d6500530b))
* **deps:** bump version to 0.1.1 in uv.lock ([55509f9](https://github.com/TheoEwzZer/WinSight-MCP/commit/55509f9df22184b680d64eb6dd2f722a14d0a6c5))
* **deps:** remove unused pygetwindow and pyautogui ([58bb650](https://github.com/TheoEwzZer/WinSight-MCP/commit/58bb650ac0810b99adafb4d7980e2acacf3a97ea))
* **deps:** update uv.lock after removing unused dependencies ([7e6f483](https://github.com/TheoEwzZer/WinSight-MCP/commit/7e6f4832ae4753b11ed7f92c167f55996f7bd090))
* enable bump-minor-pre-major in release-please ([f54633a](https://github.com/TheoEwzZer/WinSight-MCP/commit/f54633ae56aefa72ca6bb1e7611f71beaa44362a))


### CI

* add release workflow with release-please and PyPI publish ([cfafeb8](https://github.com/TheoEwzZer/WinSight-MCP/commit/cfafeb8955386d7471f0dd670657ea2d7eb540a7))
* amend release commit with uv.lock instead of separate commit ([2915c6f](https://github.com/TheoEwzZer/WinSight-MCP/commit/2915c6f58cb922446a00fd46515fb7c7d116cc66))


### Tests

* add comprehensive test suite with 112 tests ([ff462af](https://github.com/TheoEwzZer/WinSight-MCP/commit/ff462af71ca20e333eeb2a40ccc11ad89bef4f63))


### Reverts

* use separate commit for uv.lock update ([abf1953](https://github.com/TheoEwzZer/WinSight-MCP/commit/abf195322b7f1157e93908404256de3bc94e61d9))
